@@ -44,6 +44,8 @@ class NumpyToTensor(AbstractTransform):
                 tensor = tensor.float()
             elif self.cast_to == 'long':
                 tensor = tensor.long()
+            elif self.cast_to == 'bool':
+                tensor = tensor.bool()
             else:
                 raise ValueError('Unknown value for cast_to: %s' % self.cast_to)
         return tensor
